"""
SBMLLayout — clean API for the SBML Layout extension.

Quick start::

    import SBMLLayout as sl

    layout = sl.Layout(sbml_string)
    layout.addNode('S1', x=160, y=100, w=50, h=45)
    layout.addNode('A',  x=60,  y=200, w=50, h=40)
    layout.addNode('A',  x=280, y=300, w=50, h=40, alias=True)
    layout.addReaction('J1', center=(184, 205),
                       reactants=['S1'], products=['S2', 'A'])
    layout.addReaction('J2', center=(185, 346),
                       reactants=['S2', 'A:1'], products=['S3'])
    sbml = layout.toSBML()
"""

from .layout import Layout

__version__ = '0.2.0'
__all__ = ['Layout']
