from setuptools import setup, find_packages

setup(
    name='SBMLLayout',
    version='0.2.0',
    description='Clean API for reading and writing the SBML Layout extension',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Herbert Sauro',
    packages=['SBMLLayout'],          # explicit, not find_packages()
    package_dir={'SBMLLayout': 'SBMLLayout'},
    python_requires='>=3.8',
    install_requires=['python-libsbml'],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
    ],
)
